According to the file pci-ids.txt in qemu sources, the range of PCI
device IDs assigned to virtio_pci is 0x1000 to 0x10ff, with a few
subranges that have different rules regarding who can get an ID
there and how.

Nevertheless, the full range should be assigned to the generic
virtio_pci driver, so that all corresponding devices, including
the experimental/unreleased ones "just work".
---
 drivers/virtio/virtio_pci.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/virtio/virtio_pci.c b/drivers/virtio/virtio_pci.c
index 330aacb..db3f3b5 100644
--- a/drivers/virtio/virtio_pci.c
+++ b/drivers/virtio/virtio_pci.c
@@ -325,8 +325,8 @@ static int __devinit virtio_pci_probe(struct pci_dev 
*pci_dev,
        struct virtio_pci_device *vp_dev;
        int err;
 
-       /* We only own devices >= 0x1000 and <= 0x103f: leave the rest. */
-       if (pci_dev->device < 0x1000 || pci_dev->device > 0x103f)
+       /* We only own devices >= 0x1000 and <= 0x10ff: leave the rest. */
+       if (pci_dev->device < 0x1000 || pci_dev->device > 0x10ff)
                return -ENODEV;
 
        if (pci_dev->revision != VIRTIO_PCI_ABI_VERSION) {
-- 
1.5.6.3

--
To unsubscribe from this list: send the line "unsubscribe kvm" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to